<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 6837 $ -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name> 案内ページ</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="70%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000"><MM-List-Name>について</FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="30%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start> <MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>

	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> このメーリングリストに投稿された過去のメールは,
	      <MM-Archive><MM-List-Name>
		  保存書庫</MM-Archive>をご覧下さい.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000"><MM-List-Name> の利用法</FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  メーリングリストの全会員に送るメールは, 
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>
          のアドレス宛に送信してください.

	  <p>メーリングリストの入会や現在の会員オプションの変更は, 
          以下のフォームをご利用ください.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000"><MM-List-Name> の購読</FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    <MM-List-Name> への入会は, 
            以下のフォームに必要事項を記入してください. 
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">メールアドレス:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
        <td bgcolor="#dddddd" width="55%">名前 (省略可):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>情報の保護に使うパスワードを
	指定することもできます. 高度なセキュリティではありませんが,
	他人に会員情報を変更されることを防ぐことはできるはずです. 
	このパスワードは, 暗号化せずにメールで送信される場合があります
	ので, システムパスワードなどの <b>重要なパスワードを指定しない
	</b>ようにしてください.
	<br>
	パスワードが指定されなかった場合, パスワードを自動的に生成して
	入会確認後にメールで送付します. 
	いつでもこのパスワードをメールで取り寄せることができます.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">パスワードを入力してください:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">確認のため同じパスワードを再入力:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">表示に使う言語を選んでください</TD>
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>リストのメールを毎日1本にまとめて送りますか?
	  </td>
	<td><MM-Undigest-Radio-Button> いいえ
	    <MM-Digest-Radio-Button>  はい
	</TD>
      </tr>
      <mm-digest-question-end>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000"><MM-List-Name> 会員の方へ</FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
        <MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
