Cererile administrative sunt afişate în unul din cele două moduri,
pe o <a href="%(summaryurl)s">pagină de sumar</a>, şi respectiv pe
o pagină de <em>detalii</em>.  Pagina de sumar conţine cererile de
abonare şi cele de părăsire a listei, precum şi mesajele reţinute
pentru aprobare, grupate după adresa de email a expeditorului.
Pagina de detalii conţine o imagine mai detaliată a fiecărui mesaj
reţinut, incluzând toate headerele acestuia şi un extras al corpului
mesajului.

<p>Pe toate paginile, următoarele acţiuni sunt disponibile:

<ul>
<li><b>Amânare</b> -- Amânaţi luarea unei decizii pentru mai târziu.
    Nu este execută nici o acţiune pentru această cerere administrativă
    în aşteptare, dar pentru mesajele reţinute, mai puteţi re-trimite
    (forward) sau păstra mesajul (vezi mai jos).

<li><b>Aprobare</b> -- Aprobaţi mesajul, trimiţându-l listei. În cazul
    cererilor legate de abonament, este aprobată schimbarea cerută.

<li><b>Respingere</b> -- Mesajul este respins, fiind trimisă o notă cu
    explicaţia refuzului către expeditor.  În cazul cererilor legate de
    abonament, este refuzată cererea de schimbare a abonamentului.
    În oricare din cazuri, este indicat să adăugaţi şi un motiv al respingerii
    cererii în câmpul de alături.

<li><b>Ignorare</b> -- Mesajul iniţial este ignorat, fără a fi trimisă vreo
    notă a respingerii acestuia.  În cazul cererilor legate de abonament,
    cererea este pur şi simplu ignorată, fără notificarea iniţiatorului.
    Aceasta este acţiunea cel mai des folosită în cazul situaţiilor de spam.
</ul>

<p>În cazul mesajelor reţinute, bifaţi opţiunea <b>Păstrează</b> dacă doriţi
să salvaţi o copie a mesajului pentru administratorul site-ului.  Acest fapt
este foarte folositor în cazul mesajelor abuzive pe care doriţi să le ignoraţi,
dar trebuie să le păstraţi pentru o inspecţie ulterioară.

<p>Bifaţi opţiunea <b>Retrimite la </b>, şi completaţi adresa de destinaţie
dacă doriţi să trimiteţi mesajul către o adresă ce nu se află pe listă.
Pentru a edita un mesaj reţinut înainte de a fi trimis listei, va trebui
să retrimiteţi mesajul către dumneavoastră (sau către proprietarii listei),
şi să ignoraţi mesajul iniţial.  Apoi, când mesajul vă apare în căsuţa
postală, faceţi modificările cuvenite şi retrimiteţi-l către listă, incluzând
un header <tt>Approved:</tt> având parola listei ca valoare.  Neticheta
(regulile de politeţe pe net) recomandă adăugarea unei note prin care să
prezentaţi motivul modificărilor făcute.

<p>Dacă expeditorul este un membru supravegheat (moderat) al listei, opţional
puteţi reseta flag-ul de moderare.  Această facilitate este utilă când lista
dumneavoastra este configurata sa ţina noii membrii într-o perioadă de probă,
si aţi decis că acest membru este de încredere şi poate trimite direct mesaje
către, listă fără alte aprobări.

<p>Dacă expeditorul nu este un membru al listei, puteţi adăuga adresa de email
unui <em>filtru de expeditori</em>.  Filtrele de expeditori sunt descrise pe
<a href="%(filterurl)s">pagina de filtre a informaţiilor personale</a>,
şi poate fi unul din <b>auto-accept</b> (Acceptare), <b>auto-hold</b> (Reţinere),
<b>auto-reject</b> (Respingere), sau <b>auto-discard</b> (Ignorare).  Această opţiune
nu va fi disponibilă dacă adresa este deja ataşată unui filtru de expeditor.

<p>Când aţi terminat, apăsaţi pe butonul <em>Salvează toate datele</em> (aflat la
extremităţile paginii).  Acest buton va trimite spre executare toate acţiunile selectate
pentru toate cererile administrative pentru care aţi luat o decizie.

<p><a href="%(summaryurl)s">Înapoi la pagina de sumar</a>.
